Module console

Module console 

Console I/O module.

This module is designed so that it can be replaced with a different console implementation if necessary - it is an abstraction over tcod.

Modules

input

Structs

Color
Color struct.
ConsoleSettings
DrawConsole
Console object responsible for display and input.
EventFlags
Key

Enums

Event
KeyCode