Console I/O module.
This module is designed so that it can be replaced with a different console implementation if necessary - it is an abstraction over tcod.
Modules
Structs
- Color
- Color struct.
- Console
Settings - Draw
Console - Console object responsible for display and input.
- Event
Flags - Key